/******************************************************************************
 *
 * Filename: errors.c
 *
 * Author:   Robert Thornburrow
 * Project:  Cycle - The CYbot Control LanguagE
 * Created:  5th July 2003
 *
 * Purpose:  Error printing routines.
 *
 * (c) Copyright R.H.Thornburrow, 2003
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 *****************************************************************************/

#include <stdio.h>

#include "config.h"
#include "errors.h"
#include "cycdefs.h"


extern const char *infile;
extern int _lineNo;
extern int errors;
extern int warnings;
extern int verbose;


void syntax_error( const char* msg )
{
	fprintf( stderr, "\"%s\", line %d: syntax error: %s\n", infile, _lineNo, msg );
	errors++;
}


void semantic_warning( const char* msg, LineNumber* lineNo )
{
	if( lineNo )
		fprintf( stderr, "\"%s\", line %d: warning: %s\n", lineNo->filename, lineNo->line, msg );
	else
		fprintf( stderr, "\"%s\": warning: %s\n", infile, msg );
	warnings++;
}


void semantic_warning1( const char* msg, LineNumber* lineNo, const char* s1 )
{
	char buf[256];
	sprintf( buf, msg, s1 );
	semantic_warning( buf, lineNo );
}


void semantic_error( const char* msg, LineNumber* lineNo )
{
	if( lineNo )
		fprintf( stderr, "\"%s\", line %d: error: %s\n", lineNo->filename, lineNo->line, msg );
	else
		fprintf( stderr, "\"%s\": error: %s\n", infile, msg );
	errors++;
}


void semantic_error1( const char* msg, LineNumber* lineNo, const char* s1 )
{
	char buf[256];
	sprintf( buf, msg, s1 );
	semantic_error( buf, lineNo );
}


void semantic_error2( const char* msg, LineNumber* lineNo, const char* s1, const char *s2 )
{
	char buf[256];
	sprintf( buf, msg, s1, s2 );
	semantic_error( buf, lineNo );
}

void codegen_error( const char* msg, LineNumber* lineNo )
{
	if( lineNo )
		fprintf( stderr, "\"%s\", line %d: error: %s\n", lineNo->filename, lineNo->line, msg );
	else
		fprintf( stderr, "\"%s\": error: %s\n", infile, msg );
	errors++;
}


void codegen_error1( const char* msg, LineNumber* lineNo, const char *s1 )
{
	char buf[256];
	sprintf( buf, msg, s1 );
	codegen_error( buf, lineNo );
}


void codegen_error2( const char* msg, LineNumber* lineNo, const char *s1, const char *s2 )
{
	char buf[256];
	sprintf( buf, msg, s1, s2 );
	codegen_error( buf, lineNo );
}


void codegen_warning1( const char* msg, LineNumber* lineNo, const char *s1 )
{
	char buf[256];
	sprintf( buf, msg, s1 );
	if( lineNo )
		fprintf( stderr, "\"%s\", line %d: warning: %s\n", lineNo->filename, lineNo->line, buf );
	else
		fprintf( stderr, "\"%s\": warning: %s\n", infile, buf );
	warnings++;
}


void verbose_msg( const char* file, const char *msg )
{
	if( verbose)
		fprintf( stderr, PROGNAME ": \"%s\" %s\n", file, msg );
}


void verbose_msg1( const char* file, const char *msg, const char *s1 )
{
	if( verbose)
	{
		char buf[256];
		sprintf( buf, msg, s1 );
		fprintf( stderr, PROGNAME ": \"%s\" %s\n", file, buf );
	}
}
