/******************************************************************************
 *
 * Filename: errors.h
 *
 * Author:   Robert Thornburrow
 * Project:  Cycle - The CYbot Control LanguagE
 * Created:  5th July 2003
 *
 * Purpose:  Error printing routines.
 *
 * (c) Copyright R.H.Thornburrow, 2003
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 *****************************************************************************/

#ifndef __errors_h

#define __errors_h


#ifdef __cplusplus
extern "C" {
#endif

struct LineNumber;

extern void syntax_error( const char* msg );

extern void semantic_warning( const char* msg, struct LineNumber* lineNo );
extern void semantic_warning1( const char* msg, struct LineNumber* lineNo, const char* s1 );

extern void semantic_error( const char* msg, struct LineNumber* lineNo );
extern void semantic_error1( const char* msg, struct LineNumber* lineNo, const char* s1 );
extern void semantic_error2( const char* msg, struct LineNumber* lineNo, const char* s1, const char *s2 );

extern void codegen_warning1( const char* msg, struct LineNumber* lineNo, const char *s1 );

extern void codegen_error( const char* msg, struct LineNumber* lineNo );
extern void codegen_error1( const char* msg, struct LineNumber* lineNo, const char *s1 );
extern void codegen_error2( const char* msg, struct LineNumber* lineNo, const char *s1, const char *s2 );

extern void verbose_msg( const char* file, const char *msg );
extern void verbose_msg1( const char* file, const char *msg, const char *s1 );


#ifdef __cplusplus
}
#endif

#endif /* __errors_h */
